aboutsummaryrefslogtreecommitdiff
path: root/gui/massadd.cpp
diff options
context:
space:
mode:
authorBastien Bouclet2016-09-15 18:39:45 +0200
committerBastien Bouclet2019-11-03 11:43:00 +0100
commitbb813719b56a3e2a51b7c73385d036f61fdde584 (patch)
tree098d51552ed8a5afde854cd8ed00a5f3d7ddc87e /gui/massadd.cpp
parent9c8bd056d6d597a10f7f653b559dc34cd2bd2be9 (diff)
downloadscummvm-rg350-bb813719b56a3e2a51b7c73385d036f61fdde584.tar.gz
scummvm-rg350-bb813719b56a3e2a51b7c73385d036f61fdde584.tar.bz2
scummvm-rg350-bb813719b56a3e2a51b7c73385d036f61fdde584.zip
ENGINES: Change targets to have an 'engine ID'
The engine ID identifies which engine should be used to launch the target. Also remove the 'single ID' system. Different games from engines that used that system now have different game IDs. Also-By: Matthew Hoops <clone2727@gmail.com>
Diffstat (limited to 'gui/massadd.cpp')
-rw-r--r--gui/massadd.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/gui/massadd.cpp b/gui/massadd.cpp
index f4d857a528..1d1d119303 100644
--- a/gui/massadd.cpp
+++ b/gui/massadd.cpp
@@ -207,7 +207,7 @@ void MassAddDialog::handleTickle() {
while (path != "/" && path.lastChar() == '/')
path.deleteLastChar();
// Check for existing config entries for this path/gameid/lang/platform combination
if (_pathToTargets.contains(path)) {
Common::String resultPlatformCode = Common::getPlatformCode(result.platform);
Common::String resultLanguageCode = Common::getLanguageCode(result.language);
@@ -215,11 +215,12 @@ void MassAddDialog::handleTickle() {
bool duplicate = false;
const StringArray &targets = _pathToTargets[path];
for (StringArray::const_iterator iter = targets.begin(); iter != targets.end(); ++iter) {
// If the gameid, platform and language match -> skip it
Common::ConfigManager::Domain *dom = ConfMan.getDomain(*iter);
assert(dom);
- if ((*dom)["gameid"] == result.gameId &&
+ if ((*dom)["engineid"] == result.engineId &&
+ (*dom)["gameid"] == result.gameId &&
(*dom)["platform"] == resultPlatformCode &&
(*dom)["language"] == resultLanguageCode) {
duplicate = true;
@@ -207,7 +207,7 @@ void MassAddDialog::handleTickle() {
while (path != "/" && path.lastChar() == '/')
path.deleteLastChar();
- // Check for existing config entries for this path/gameid/lang/platform combination
+ // Check for existing config entries for this path/engineid/gameid/lang/platform combination
if (_pathToTargets.contains(path)) {
Common::String resultPlatformCode = Common::getPlatformCode(result.platform);
@@ -215,11 +215,12 @@ void MassAddDialog::handleTickle() {
const StringArray &targets = _pathToTargets[path];
for (StringArray::const_iterator iter = targets.begin(); iter != targets.end(); ++iter) {
- // If the gameid, platform and language match -> skip it
+ // If the engineid, gameid, platform and language match -> skip it
Common::ConfigManager::Domain *dom = ConfMan.getDomain(*iter);
assert(dom);